==> index_now-2.0.x-dev.tar.gz: index_now/tests/src/Unit/NodeOperationsTest.php <==
<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Tests\UnitTestCase;
use Drupal\index_now\NodeOperations;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\node\Entity\Node;
use Drupal\user\Entity\Role;
use Drupal\user\RoleStorageInterface;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Tests the NodeOperations class.
 *
 * @coversDefaultClass \Drupal\index_now\NodeOperations
 *
 * @group index_now
 */
class NodeOperationsTest extends UnitTestCase {

  use ProphecyTrait;

  const CONFIG_NAME = 'index_now.settings';

  const CONFIG_EXCLUDE_NAME = 'exclude_node_types';

  const PERMISSION = 'access content';

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->configFactory = $this->prophesize(ConfigFactoryInterface::class);
    $this->entityTypeManager = $this->prophesize(EntityTypeManagerInterface::class);
    $this->indexNow = $this->prophesize(IndexNowInterface::class);

    $this->roleStorage = $this->prophesize(RoleStorageInterface::class);
    $this->entityTypeManager
      ->getStorage('user_role')
      ->willReturn($this->roleStorage->reveal());

    $this->nodeOperations = new NodeOperations(
      $this->configFactory->reveal(),
      $this->entityTypeManager->reveal(),
      $this->indexNow->reveal()
    );
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsUnpublished(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(FALSE);

    $this->roleStorage->load(Argument::any())
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testUserCantAccessContent(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(FALSE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeTypeIsExcluded(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $node->getType()
      ->ShouldBeCalled()
      ->willReturn('foo');

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsIndexable(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $node->getType()
      ->ShouldBeCalled()
      ->willReturn('bar');

    $this->assertTrue($this->nodeOperations->isIndexable($node->reveal()));
  }

}

==> index_now-3.1.x-dev.tar.gz: index_now/tests/src/Unit/NodeOperationsTest.php <==
<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\index_now\NodeOperations;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\node\Entity\Node;
use Drupal\Tests\UnitTestCase;
use Drupal\user\Entity\Role;
use Drupal\user\RoleStorageInterface;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Tests the NodeOperations class.
 *
 * @coversDefaultClass \Drupal\index_now\NodeOperations
 *
 * @group index_now
 */
class NodeOperationsTest extends UnitTestCase {

  use ProphecyTrait;

  const CONFIG_NAME = 'index_now.settings';

  const CONFIG_EXCLUDE_NAME = 'exclude_node_types';

  const CONFIG_EXCLUDE_EVENTS_NAME = 'exclude_node_events';

  const PERMISSION = 'access content';

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The Index Now service.
   *
   * @var \Drupal\index_now\Service\IndexNowInterface
   */
  protected $indexNow;

  /**
   * The role storage.
   *
   * @var \Drupal\user\RoleStorageInterface
   */
  protected $roleStorage;

  /**
   * The Index Now node operations.
   *
   * @var \Drupal\index_now\NodeOperations
   */
  protected $nodeOperations;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->configFactory = $this->prophesize(ConfigFactoryInterface::class);
    $this->entityTypeManager = $this->prophesize(EntityTypeManagerInterface::class);
    $this->indexNow = $this->prophesize(IndexNowInterface::class);

    $this->roleStorage = $this->prophesize(RoleStorageInterface::class);
    $this->entityTypeManager
      ->getStorage('user_role')
      ->willReturn($this->roleStorage->reveal());

    $this->nodeOperations = new NodeOperations(
      $this->configFactory->reveal(),
      $this->entityTypeManager->reveal(),
      $this->indexNow->reveal()
    );
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsUnpublished(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(FALSE);

    $this->roleStorage->load(Argument::any())
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal(), 'foo'));
  }

  /**
   * @covers ::isIndexable
   */
  public function testUserCantAccessContent(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(FALSE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal(), 'foo'));
  }

  /**
   * @covers ::isIndexable
   */
  public function testEventIsExcluded(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $config = $this->prophesize(Config::class);
    $config
      ->get(self::CONFIG_EXCLUDE_EVENTS_NAME)
      ->ShouldBeCalled()
      ->willReturn([
        'foo' => 'foo',
        'bar' => 0,
      ]);
    $config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->ShouldNotBeCalled();

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($config->reveal());

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal(), 'foo'));
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeTypeIsExcluded(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $config = $this->prophesize(Config::class);
    $config
      ->get(self::CONFIG_EXCLUDE_EVENTS_NAME)
      ->ShouldBeCalled()
      ->willReturn([
        'foo' => 0,
        'bar' => 0,
      ]);
    $config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->ShouldBeCalled()
      ->willReturn(['foobar']);

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($config->reveal());

    $node->getType()
      ->ShouldBeCalled()
      ->willReturn('foobar');

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal(), 'foo'));
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsIndexable(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $config = $this->prophesize(Config::class);
    $config
      ->get(self::CONFIG_EXCLUDE_EVENTS_NAME)
      ->ShouldBeCalled()
      ->willReturn([
        'foo' => 0,
        'bar' => 0,
      ]);
    $config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->ShouldBeCalled()
      ->willReturn(['barfoo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($config->reveal());

    $node->getType()
      ->ShouldBeCalled()
      ->willReturn('foobar');

    $this->assertTrue($this->nodeOperations->isIndexable($node->reveal(), 'foo'));
  }

}
